@@ -9,7 +9,7 @@ from proxmoxer import ProxmoxAPI
 from prometheus_client import CollectorRegistry, generate_latest
 from prometheus_client.core import GaugeMetricFamily
 
-class StatusCollector(object):
+class StatusCollector:
     """
     Collects Proxmox VE Node/VM/CT-Status
 
@@ -46,7 +46,7 @@ class StatusCollector(object):
 
         yield status_metrics
 
-class VersionCollector(object):
+class VersionCollector:
     """
     Collects Proxmox VE build information. E.g.:
 
@@ -74,14 +74,14 @@ class VersionCollector(object):
 
         yield metric
 
-class ClusterNodeCollector(object):
+class ClusterNodeCollector:
     """
     Collects Proxmox VE cluster node information. E.g.:
 
     # HELP pve_node_info Node info
     # TYPE pve_node_info gauge
-    pve_node_info{id="node/proxmox-host", ip="10.20.30.40", level="c",
-        local="1", name="proxmox-host", nodeid="0"} 1.0
+    pve_node_info{id="node/proxmox-host", level="c", name="proxmox-host",
+        nodeid="0"} 1.0
     """
 
     def __init__(self, pve):
@@ -89,15 +89,9 @@ class ClusterNodeCollector(object):
 
     def collect(self): # pylint: disable=missing-docstring
         nodes = [entry for entry in self._pve.cluster.status.get() if entry['type'] == 'node']
+        labels = ['id', 'level', 'name', 'nodeid']
 
         if nodes:
-            # Remove superflous keys.
-            for node in nodes:
-                del node['type']
-                del node['online']
-
-            # Yield remaining data.
-            labels = nodes[0].keys()
             info_metrics = GaugeMetricFamily(
                 'pve_node_info',
                 'Node info',
@@ -109,7 +103,7 @@ class ClusterNodeCollector(object):
 
             yield info_metrics
 
-class ClusterInfoCollector(object):
+class ClusterInfoCollector:
     """
     Collects Proxmox VE cluster information. E.g.:
 
@@ -147,7 +141,7 @@ class ClusterInfoCollector(object):
 
             yield info_metrics
 
-class ClusterResourcesCollector(object):
+class ClusterResourcesCollector:
     """
     Collects Proxmox VE cluster resources information, i.e. memory, storage, cpu
     usage for cluster nodes and guests.
@@ -202,6 +196,10 @@ class ClusterResourcesCollector(object):
                 'pve_uptime_seconds',
                 'Number of seconds since the last boot',
                 labels=['id']),
+            'shared': GaugeMetricFamily(
+                'pve_storage_shared',
+                'Whether or not the storage is shared among cluster nodes',
+                labels=['id']),
         }
 
         info_metrics = {
@@ -244,7 +242,7 @@ class ClusterResourcesCollector(object):
 
         return itertools.chain(metrics.values(), info_metrics.values())
 
-class ClusterNodeConfigCollector(object):
+class ClusterNodeConfigCollector:
     """
     Collects Proxmox VE VM information directly from config, i.e. boot, name, onboot, etc.
     For manual test: "pvesh get /nodes/<node>/<type>/<vmid>/config"
